@@ -1,22 +1,13 @@
 # coding: utf-8
 
 """
-Code to analyse VASP defect calculation results, and other dope things.
-These functions are built from a combination of extremely useful modules
-from pymatgen and AIDE (by Adam Jackson and Alex Ganose), alongside
-substantial modification, in the efforts of making an
-efficient, user-friendly package for managing and analysing defect
-calculations, with publication-quality outputs.
+Code to analyse VASP defect calculations.
+These functions are built from a combination of useful modules from pymatgen and AIDE (by Adam
+Jackson and Alex Ganose), alongside substantial modification, in the efforts of making an
+efficient, user-friendly package for managing and analysing defect calculations,
+with publication-quality outputs
 """
 
-__author__ = "Seán Kavanagh"
-__copyright__ = "MIT License"
-__version__ = "0.0.1"
-__maintainer__ = "Seán Kavanagh"
-__email__ = "sean.kavanagh.19@ucl.ac.uk"
-__date__ = "June 18, 2020"
-
-
 from operator import itemgetter
 import pickle
 from typing import Any
@@ -45,19 +36,36 @@ default_fonts = [
 ]
 
 
+def bold_print(string: str) -> None:
+    """Does what it says on the tin. Prints the input string in bold."""
+    print("\033[1m" + string + "\033[0m")
+
+
+def save_to_pickle(python_object: Any, filename: str) -> None:
+    with open(filename, "wb") as fp:
+        pickle.dump(python_object, fp)
+
+
+def load_from_pickle(filepath: str) -> None:
+    with open(filepath, "rb") as fp:
+        return pickle.load(fp)
+
+
 def dpd_from_parsed_defect_dict(parsed_defect_dict: dict) -> DefectPhaseDiagram:
-    """Generates a DefectPhaseDiagram object from a dictionary of parsed defect calculations
-    (presumably created using SingleDefectParser
-    from doped.pycdt.utils.parse_calculations), which can then be plotted (using
-    pretty_formation_energy_plot) to get formation energies, transition levels etc.
+    """Generates a DefectPhaseDiagram object from a dictionary of parsed defect calculations (
+    format: {"defect_name": defect_entry}), likely created using SingleDefectParser from
+    doped.pycdt.utils.parse_calculations), which can then be used to analyse and plot the defect
+    thermodynamics (formation energies, transition levels, concentrations etc)
+
     Args:
         parsed_defect_dict (dict):
-            Dictionary of parsed defect calculations (presumably created using SingleDefectParser
-            from doped.pycdt.utils.parse_calculations) (see example notebook)
-            Must have 'vbm' and 'gap' in defect.parameters for each defect (from
+            Dictionary of parsed defect calculations (format: {"defect_name": defect_entry}),
+            likely created using SingleDefectParser from doped.pycdt.utils.parse_calculations).
+            Must have 'vbm' and 'gap' in defect_entry.parameters for each defect (from
             SingleDefectParser.get_bulk_gap_data())
+
     Returns:
-        DefectPhaseDiagram object
+        pymatgen DefectPhaseDiagram object (DefectPhaseDiagram)
     """
     vbm_vals = []
     bandgap_vals = []
@@ -87,54 +95,18 @@ def dpd_from_parsed_defect_dict(parsed_defect_dict: dict) -> DefectPhaseDiagram:
     return dpd
 
 
-def suggest_larger_supercells(defect_phase_diagram: DefectPhaseDiagram, tolerance=0.1):
-    """
-    This is a pymatgen DefectPhaseDiagram method that has a bug in it, so I've rewritten the code
-    without the bug here.
-    Suggest larger supercells for different defect+chg combinations based on use of
-    compatibility analysis. Does this for any charged defects which have is_compatible = False,
-    and the defect+chg formation energy is stable at fermi levels within the band gap.
-    NOTE: Requires self.filter_compatible = False
-    Args:
-        tolerance (float): tolerance with respect to the VBM and CBM for considering
-                           larger supercells for a given charge
-    """
-    if defect_phase_diagram.filter_compatible:
-        raise ValueError("Cannot suggest larger supercells if filter_compatible is True.")
-    recommendations = {}
-    for def_type in defect_phase_diagram.defect_types:
-        template_entry = defect_phase_diagram.stable_entries[def_type][0].copy()
-        defect_indices = [int(def_ind) for def_ind in def_type.split("@")[-1].split("-")]
-        for charge in defect_phase_diagram.finished_charges[def_type]:
-            chg_defect = template_entry.defect.copy()
-            chg_defect.set_charge(charge)
-            for entry_index in defect_indices:
-                entry = defect_phase_diagram.entries[entry_index]
-                if entry.charge == charge:
-                    break
-            if entry.parameters.get("is_compatible", True):
-                continue
-            else:
-                # consider if transition level is within
-                # tolerance of band edges
-                suggest_bigger_supercell = True
-                for tl, chgset in defect_phase_diagram.transition_level_map[def_type].items():
-                    sorted_chgset = list(chgset)
-                    sorted_chgset.sort(reverse=True)
-                    if charge == sorted_chgset[0] and tl < tolerance:
-                        suggest_bigger_supercell = False
-                    elif charge == sorted_chgset[1] and tl > (
-                        defect_phase_diagram.band_gap - tolerance
-                    ):
-                        suggest_bigger_supercell = False
-            if suggest_bigger_supercell:
-                if def_type not in recommendations:
-                    recommendations[def_type] = []
-                recommendations[def_type].append(charge)
-    return recommendations
-
-
 def dpd_transition_levels(defect_phase_diagram: DefectPhaseDiagram):
+    """Iteratively prints the charge transition levels for the input DefectPhaseDiagram object
+    (via the from a defect_phase_diagram.transition_level_map attribute)
+
+    Args:
+        defect_phase_diagram (DefectPhaseDiagram):
+            DefectPhaseDiagram object (likely created from
+            dope_stuff.dpd_from_parsed_defect_dict)
+
+    Returns:
+        None
+    """
     for def_type, tl_info in defect_phase_diagram.transition_level_map.items():
         bold_print(f"\nDefect: {def_type.split('@')[0]}")
         for tl_efermi, chargeset in tl_info.items():
@@ -145,91 +117,53 @@ def dpd_transition_levels(defect_phase_diagram: DefectPhaseDiagram):
             )
 
 
-# def pretty_formation_energy_plot(
-#     defect_phase_diagram: DefectPhaseDiagram,
-#     chempots: dict = None,
-#     xlim: float = None,
-#     ylim: float = None,
-#     ax_fontsize: float = 1.3,
-#     lg_fontsize: float = 1.0,
-#     lg_position: tuple = None,
-#     fermi_level: float = None,
-#     title: str = None,
-#     saved: bool = False,
-# ):
-#     """
-#         Produces pretty Defect Formation Energy vs Fermi Energy plots for the defects in
-#         defect_phase_diagram, for each chemical potential limit in chempot_limits.
-#         Args:
-#             defect_phase_diagram (DefectPhaseDiagram):
-#                 DefectPhaseDiagram object for which to plot Formation Energy vs Fermi Energy
-#             chempots:
-#                 A dictionary of {Element: Energy} giving the chemical potential of each element.
-#                 If None, chemical potential is set to 0 for each element.
-#                 (default: None}
-#             xlim (tuple):
-#                 Tuple (min,max) to set the range of the x (Fermi Energy) axis
-#                 (default: None)
-#             ylim (tuple):
-#                 Tuple (min,max) to set the range for the Formation Energy axis
-#                 (default: None)
-#             ax_fontsize (float):
-#                 Float  multiplier to change axis label fontsize
-#                 (default: 1.3)
-#             lg_fontsize (float):
-#                 Float  multiplier to change legend label fontsize
-#                 (default: 1.0)
-#             lg_position (tuple):
-#                 Tuple (horizontal-position, vertical-position) giving the fractional position
-#                 to place the legend.
-#                 Example: (0.5,-0.75) will likely put it below the x-axis.
-#                 (default: None)
-#             fermi_level (float):
-#                 Plot the specified Fermi Level position as a vertical line.
-#                 (default: None)
-#             title (str):
-#                 Title of plot.
-#                 (default: None)
-#             saved (bool):
-#                 Whether to save the plot as an image file.
-#                 (default: False)
-#         Returns:
-#             A matplotlib plot object
-#         """
-#     plot = defect_phase_diagram.plot(
-#         mu_elts=chempots,
-#         xlim=xlim,
-#         ylim=ylim,
-#         ax_fontsize=ax_fontsize,
-#         lg_fontsize=lg_fontsize,
-#         lg_position=lg_position,
-#         fermi_level=fermi_level,
-#         title=title,
-#         saved=saved,
-#     )
-#     for i in defect_phase_diagram.transition_level_map.values():
-#         for trans_level, charges in i.items():
-#             plot.vlines(trans_level, *plot.ylim(), colors="cyan", linestyles="dashdot")
-#             plot.annotate(
-#                 f"({max(charges)}/{min(charges)})", (trans_level + 0.02, plot.ylim()[1] - 0.2)
-#             )
-#
-#     return plot
-
-
 def formation_energy_table(
     defect_phase_diagram: DefectPhaseDiagram,
     chempot_limits: dict = None,
+    pd_facets: list = None,
     fermi_level: float = 0,
     hide_cols: list = None,
     show_key: bool = True,
-    pd_facets: list = None,
 ):
     """
-        Prints the formation energy tables for either a single chemical potential limit (i.e. phase
-        diagram facet) or each facet in the chempot_limits dict, depending on which version you
-        provide. Returns the results as either a pandas dataframe or list of dataframes.
-        """
+    Prints defect formation energy tables for either a single chemical potential limit (i.e. phase
+    diagram facet) or each facet in the phase diagram (chempot_limits dict), depending on the
+    chempot_limits input supplied. This can either be a dictionary of chosen absolute/DFT chemical
+    potentials: {Elt: Energy} (giving a single formation energy table) or a dictionary including
+    the key-value pair: {"facets": [{'facet': [chempot_dict]}]}, following the format generated
+    by chempot_limits = cpa.read_phase_diagram_and_chempots() (see example notebooks). In the
+    latter case, a subset of facet(s) / chemical potential limit(s) can be chosen with the
+    pd_facets argument, or if not specified, will print formation energy tables for each facet in
+    the phase diagram.
+    Returns the results a pandas DataFrame or list of DataFrames.
+
+    Args:
+        defect_phase_diagram (DefectPhaseDiagram):
+             DefectPhaseDiagram object (likely created from
+             dope_stuff.dpd_from_parsed_defect_dict)
+        chempot_limits (dict):
+            This can either be a dictionary of chosen absolute/DFT chemical potentials: {Elt:
+            Energy} (giving a single formation energy table) or a dictionary including the
+            key-value pair: {"facets": [{'facet': [chempot_dict]}]}, following the format generated
+            by chempot_limits = cpa.read_phase_diagram_and_chempots() (see example notebooks). If
+            not specified, chemical potentials are not included in the formation energy calculation
+            (all set to zero energy).
+        pd_facets (list):
+            A list facet(s) / chemical potential limit(s) for which to print the defect formation
+            energy tables. If not specified, will print formation energy tables for each facet in
+            the phase diagram. (default: None)
+        fermi_level (float):
+            Fermi level to use for computing the defect formation energies. (default: 0 (i.e.
+            at the VBM))
+        hide_cols: (list):
+            List of columns to hide from the output. (default: None)
+        show_key (bool):
+            Whether or not to print the table key at the bottom of the output. (default: True)
+
+    Returns:
+        pandas DataFrame or list of DataFrames
+    """
+    if chempot_limits is None: chempot_limits = {}
     if "facets" in chempot_limits:
         list_of_dfs = []
         if not pd_facets:
@@ -249,7 +183,7 @@ def formation_energy_table(
 
         return list_of_dfs
 
-    else:  # If you only want to give {Elt: Energy} dict for chempot_limits
+    else:  # {Elt: Energy} dict for chempot_limits, or if unspecified, all zero energy
         df = single_formation_energy_table(
             defect_phase_diagram,
             chempots=chempot_limits,
@@ -268,25 +202,44 @@ def single_formation_energy_table(
     show_key: bool = True,
 ):
     """
-    Prints the formation energy table for a single chemical potential limit (i.e. phase diagram
-    facet), and returns the results as a pandas dataframe.
+    Prints a defect formation energy table for a single chemical potential limit (i.e. phase diagram
+    facet), and returns the results as a pandas DataFrame.
+
+    Args:
+        defect_phase_diagram (DefectPhaseDiagram):
+             DefectPhaseDiagram object (likely created from
+             dope_stuff.dpd_from_parsed_defect_dict)
+        chempots (dict):
+            Dictionary of chosen absolute/DFT chemical potentials: {Elt: Energy}. If not
+            specified, chemical potentials are not included in the formation energy calculation
+            (all set to zero energy).
+        fermi_level (float):
+            Fermi level to use for computing the defect formation energies. (default: 0 (i.e.
+            at the VBM))
+        hide_cols: (list):
+            List of columns to hide from the output. (default: None)
+        show_key (bool):
+            Whether or not to print the table key at the bottom of the output. (default: True)
+
+    Returns:
+        pandas DataFrame sorted by formation energy
     """
     header = ["Defect", "Charge", "Defect Path"]
     table = []
-    if hide_cols is None:
-        hide_cols = []
+    if hide_cols is None: hide_cols = []
+
     for defect_entry in defect_phase_diagram.entries:
         row = [defect_entry.name, defect_entry.charge, defect_entry.parameters["defect_path"]]
-        if "Uncorrected_E" not in hide_cols:
-            header += ["Uncorrected_E"]
+        if "Uncorrected Energy" not in hide_cols:
+            header += ["Uncorrected Energy"]
             row += [f"{defect_entry.uncorrected_energy:.2f} eV"]
-        if "Corrected_E" not in hide_cols:
-            header += ["Corrected_E"]
+        if "Corrected Energy" not in hide_cols:
+            header += ["Corrected Energy"]
             row += [
                 f"{defect_entry.energy:.2f} eV"
             ]  # With 0 chemical potentials, at the calculation
             # fermi level
-        header += ["Formation_E"]
+        header += ["Formation Energy"]
         row += [
             f"{defect_entry.formation_energy(chemical_potentials=chempots, fermi_level=fermi_level):.2f} eV"
         ]
@@ -303,38 +256,24 @@ def single_formation_energy_table(
         print(
             """'Defect' -> Defect Type and Multiplicity
 'Charge' -> Defect Charge State
-'Uncorrected_E' -> Defect Energy from calculation, without corrections
-'Corrected_E' -> Defect Energy from calculation (E_defect - E_host + corrections)
+'Uncorrected Energy' -> Defect Energy from calculation, without corrections
+'Corrected Energy' -> Defect Energy from calculation (E_defect - E_host + corrections)
 (chemical potentials set to 0 and the fermi level at average electrostatic potential in the
 supercell)
-'Formation_E' -> Final Defect Formation Energy, with the specified chemical potentials (
+'Formation Energy' -> Final Defect Formation Energy, with the specified chemical potentials (
 chempot_limits)(default: all 0) and the chosen fermi_level (default: 0)(i.e. at the VBM)
         """
         )
 
     sorted_df = pd.DataFrame(
         table,
-        columns = ['Defect', 'Charge', 'defect_path', 'Uncorrected_E', 'Corrected_E', 'Formation_E']
+        columns=["Defect", "Charge", "Defect Path", "Uncorrected Energy", "Corrected Energy",
+                 "Formation Energy"],
     )
-    sorted_df = sorted_df.sort_values('Formation_E')
+    sorted_df = sorted_df.sort_values("Formation Energy")
     return sorted_df
 
 
-def bold_print(string: str) -> None:
-    """Does what it says on the tin. Prints the input string in bold."""
-    print("\033[1m" + string + "\033[0m")
-
-
-def save_to_pickle(python_object: Any, filename: str) -> None:
-    with open(filename, "wb") as fp:
-        pickle.dump(python_object, fp)
-
-
-def load_from_pickle(filepath: str) -> None:
-    with open(filepath, "rb") as fp:
-        return pickle.load(fp)
-
-
 def formation_energy_plot(
     defect_phase_diagram,
     chempot_limits=None,
@@ -351,12 +290,42 @@ def formation_energy_plot(
     colormap="Dark2",
     minus_symbol="-",
     frameon=False,
-    chem_pot_table=True,
+    chempot_table=True,
     pd_facets: list = None,
     auto_labels: bool = False,
     filename: str = None,
     emphasis=False,
 ):
+    """Produce a defect formation energy vs Fermi energy plot (i.e. a defect transition level
+    diagram).
+
+    Args:
+        defect_phase_diagram (DefectPhaseDiagram):
+             DefectPhaseDiagram object (likely created from
+             dope_stuff.dpd_from_parsed_defect_dict)
+        chempots (dict):
+            Dictionary of chosen absolute/DFT chemical potentials: {Elt: Energy}. If not
+            specified, chemical potentials are not included in the formation energy calculation
+            (all set to zero energy).
+        fermi_level (float):
+            Fermi level to use for computing the defect formation energies. (default: 0 (i.e.
+            at the VBM))
+        xlim:
+            Tuple (min,max) giving the range of the x (fermi energy) axis. This may need to be
+            set manually when including transition level labels, so that they dont' cross the axes.
+        ylim:
+            Tuple (min,max) giving the range for the formation energy axis. This may need to be
+            set manually when including transition level labels, so that they dont' cross the axes.
+        ax_fontsize:
+            float  multiplier to change axis label fontsize
+        lg_fontsize:
+            float  multiplier to change legend label fontsize
+        lg_position:
+            Tuple (horizontal-position, vertical-position) giving the position
+            to place the legend.
+            Example: (0.5,-0.75) will likely put it below the x-axis.
+    Returns:
+        a matplotlib object"""
     if chempot_limits and "facets" in chempot_limits:
         if not pd_facets:
             pd_facets = chempot_limits["facets"].keys()  # Phase diagram facets to use for chemical
@@ -386,7 +355,7 @@ def formation_energy_plot(
                 colormap=colormap,
                 minus_symbol=minus_symbol,
                 frameon=frameon,
-                chem_pot_table=chem_pot_table,
+                chempot_table=chempot_table,
                 auto_labels=auto_labels,
                 filename=filename,
                 emphasis=emphasis,
@@ -409,7 +378,7 @@ def formation_energy_plot(
             colormap=colormap,
             minus_symbol=minus_symbol,
             frameon=frameon,
-            chem_pot_table=chem_pot_table,
+            chempot_table=chempot_table,
             auto_labels=auto_labels,
             filename=filename,
             emphasis=emphasis,
@@ -433,7 +402,7 @@ def _aide_pmg_plot(
     colormap="Dark2",
     minus_symbol="-",
     frameon=False,
-    chem_pot_table=True,
+    chempot_table=True,
     auto_labels=False,
     filename=None,
     emphasis=False,
@@ -458,7 +427,6 @@ def _aide_pmg_plot(
             Tuple (horizontal-position, vertical-position) giving the position
             to place the legend.
             Example: (0.5,-0.75) will likely put it below the x-axis.
-        saved:
     Returns:
         a matplotlib object
     """
@@ -466,7 +434,7 @@ def _aide_pmg_plot(
     if xlim is None:
         xlim = (-0.4, defect_phase_diagram.band_gap + 0.4)
     xy = {}
-    all_lines_xy = {} # For emphasis plots with faded grey E_form lines for all charge states
+    all_lines_xy = {}  # For emphasis plots with faded grey E_form lines for all charge states
     lower_cap = -100.0
     upper_cap = 100.0
     y_range_vals = []  # for finding max/min values on y-axis based on x-limits
@@ -716,7 +684,7 @@ some defects will have the same line colour). Recommended to change/set colormap
     ax.yaxis.set_minor_locator(ticker.AutoMinorLocator(2))
     ax.xaxis.set_major_formatter(_CustomScalarFormatter(minus_symbol=minus_symbol))
     ax.yaxis.set_major_formatter(_CustomScalarFormatter(minus_symbol=minus_symbol))
-    if chem_pot_table:
+    if chempot_table:
         if elt_refs:
             _plot_chemical_potential_table(
                 plt,
@@ -736,12 +704,13 @@ some defects will have the same line colour). Recommended to change/set colormap
                 wrt_elt_refs=False,
             )
 
-    if title and chem_pot_table:
-        ax.set_title(latexify(title), size=1.2 * ax_fontsize * width, pad=28, fontdict={
-            "fontweight": "bold"})
+    if title and chempot_table:
+        ax.set_title(
+            latexify(title), size=1.2 * ax_fontsize * width, pad=28, fontdict={"fontweight": "bold"}
+        )
     elif title:
         ax.set_title(latexify(title), size=ax_fontsize * width, fontdict={"fontweight": "bold"})
-    if saved and filename:
+    if saved or filename:
         if filename:
             plt.savefig(filename, bbox_inches="tight", dpi=600)
         else:
@@ -752,7 +721,7 @@ some defects will have the same line colour). Recommended to change/set colormap
 def _plot_chemical_potential_table(
     plt,
     elt_refs,
-    chem_pot_label="",
+    chempot_label="",
     fontsize=9,
     loc="left",
     ax=None,
@@ -770,7 +739,7 @@ def _plot_chemical_potential_table(
     labels[1] = "(" + labels[1]
     labels[-1] = labels[-1][:-1] + ")"
     labels = ["Chemical Potentials"] + labels + [" Units:"]
-    text = [[chem_pot_label]]
+    text = [[chempot_label]]
 
     for el in sorted(chemical_potentials.keys()):
         text[0].append("{:.2f},".format(chemical_potentials[el]).replace("-", minus_symbol))
@@ -846,19 +815,19 @@ def pretty_axis(ax=None, fonts=None):
 
 def lany_zunger_corrected_defect_dict_from_freysoldt(defect_dict: dict):
     """Convert input parsed defect dictionary (presumably created using SingleDefectParser
-     from doped.pycdt.utils.parse_calculations) with Freysoldt charge corrections to
-     the same parsed defect dictionary but with the Lany-Zunger charge correction (same potential
-     alignment plus 0.65 * Makov-Payne image charge correction (same image charge correction as
-     Freysoldt scheme)).
-     Args:
-         parsed_defect_dict (dict):
-             Dictionary of parsed defect calculations (presumably created using SingleDefectParser
-             from doped.pycdt.utils.parse_calculations) (see example notebook)
-             Must have 'freysoldt_meta' in defect.parameters for each charged defect (from
-             SingleDefectParser.freysoldt_loader())
-     Returns:
-         Parsed defect dictionary with Lany-Zunger charge corrections.
-     """
+    from doped.pycdt.utils.parse_calculations) with Freysoldt charge corrections to
+    the same parsed defect dictionary but with the Lany-Zunger charge correction (same potential
+    alignment plus 0.65 * Makov-Payne image charge correction (same image charge correction as
+    Freysoldt scheme)).
+    Args:
+        parsed_defect_dict (dict):
+            Dictionary of parsed defect calculations (presumably created using SingleDefectParser
+            from doped.pycdt.utils.parse_calculations) (see example notebook)
+            Must have 'freysoldt_meta' in defect.parameters for each charged defect (from
+            SingleDefectParser.freysoldt_loader())
+    Returns:
+        Parsed defect dictionary with Lany-Zunger charge corrections.
+    """
     random_defect_entry = list(defect_dict.values())[0]  # Just need any DefectEntry from
     # defect_dict to get the lattice and dielectric matrix
     lattice = random_defect_entry.bulk_structure.lattice.matrix
@@ -895,18 +864,18 @@ def lany_zunger_corrected_defect_dict_from_freysoldt(defect_dict: dict):
 
 def lany_zunger_corrected_defect_dict_from_kumagai(defect_dict: dict):
     """Convert input parsed defect dictionary (presumably created using SingleDefectParser
-     from doped.pycdt.utils.parse_calculations) with Kumagai charge corrections to
-     the same parsed defect dictionary but with the 'Lany-Zunger' charge correction (same potential
-     alignment plus 0.65 * image charge correction.
-     Args:
-         parsed_defect_dict (dict):
-             Dictionary of parsed defect calculations (presumably created using SingleDefectParser
-             from doped.pycdt.utils.parse_calculations) (see example notebook)
-             Must have 'kumagai_meta' in defect.parameters for each charged defect (from
-             SingleDefectParser.kumagai_loader())
-     Returns:
-         Parsed defect dictionary with Lany-Zunger charge corrections.
-     """
+    from doped.pycdt.utils.parse_calculations) with Kumagai charge corrections to
+    the same parsed defect dictionary but with the 'Lany-Zunger' charge correction (same potential
+    alignment plus 0.65 * image charge correction.
+    Args:
+        parsed_defect_dict (dict):
+            Dictionary of parsed defect calculations (presumably created using SingleDefectParser
+            from doped.pycdt.utils.parse_calculations) (see example notebook)
+            Must have 'kumagai_meta' in defect.parameters for each charged defect (from
+            SingleDefectParser.kumagai_loader())
+    Returns:
+        Parsed defect dictionary with Lany-Zunger charge corrections.
+    """
     random_defect_entry = list(defect_dict.values())[0]  # Just need any DefectEntry from
     # defect_dict to get the lattice and dielectric matrix
     lattice = random_defect_entry.bulk_structure.lattice.matrix
@@ -957,7 +926,7 @@ def all_lines_formation_energy_plot(
     colormap="Dark2",
     minus_symbol="-",
     frameon=False,
-    chem_pot_table=True,
+    chempot_table=True,
     pd_facets: list = None,
     auto_labels: bool = False,
     filename: str = None,
@@ -977,7 +946,7 @@ def all_lines_formation_energy_plot(
             else:
                 plot_title = facet
 
-            _all_lines_aide_pmg_plot(
+            return _all_lines_aide_pmg_plot(
                 defect_phase_diagram,
                 mu_elts=mu_elts,
                 elt_refs=elt_refs,
@@ -994,12 +963,12 @@ def all_lines_formation_energy_plot(
                 colormap=colormap,
                 minus_symbol=minus_symbol,
                 frameon=frameon,
-                chem_pot_table=chem_pot_table,
+                chempot_table=chempot_table,
                 auto_labels=auto_labels,
                 filename=plot_filename,
             )
     else:  # If you only want to give {Elt: Energy} dict for chempot_limits, or no chempot_limits
-        _all_lines_aide_pmg_plot(
+        return _all_lines_aide_pmg_plot(
             defect_phase_diagram,
             mu_elts=chempot_limits,
             elt_refs=None,
@@ -1016,7 +985,7 @@ def all_lines_formation_energy_plot(
             colormap=colormap,
             minus_symbol=minus_symbol,
             frameon=frameon,
-            chem_pot_table=chem_pot_table,
+            chempot_table=chempot_table,
             auto_labels=auto_labels,
             filename=filename,
         )
@@ -1039,7 +1008,7 @@ def _all_lines_aide_pmg_plot(
     colormap="Dark2",
     minus_symbol="-",
     frameon=False,
-    chem_pot_table=True,
+    chempot_table=True,
     auto_labels=False,
     filename=None,
 ):
@@ -1063,7 +1032,6 @@ def _all_lines_aide_pmg_plot(
             Tuple (horizontal-position, vertical-position) giving the position
             to place the legend.
             Example: (0.5,-0.75) will likely put it below the x-axis.
-        saved:
     Returns:
         a matplotlib object
     """
@@ -1212,7 +1180,7 @@ some defects will have the same line colour). Recommended to change/set colormap
     ax.yaxis.set_minor_locator(ticker.AutoMinorLocator(2))
     ax.xaxis.set_major_formatter(_CustomScalarFormatter(minus_symbol=minus_symbol))
     ax.yaxis.set_major_formatter(_CustomScalarFormatter(minus_symbol=minus_symbol))
-    if chem_pot_table:
+    if chempot_table:
         if elt_refs:
             _plot_chemical_potential_table(
                 plt,
@@ -1232,10 +1200,10 @@ some defects will have the same line colour). Recommended to change/set colormap
                 wrt_elt_refs=False,
             )
 
-    if title and chem_pot_table:
-        ax.set_title(latexify(title), size=1.2 * ax_fontsize * width, pad=28, fontdict={
-            "fontweight":
-                                                                                   "bold"})
+    if title and chempot_table:
+        ax.set_title(
+            latexify(title), size=1.2 * ax_fontsize * width, pad=28, fontdict={"fontweight": "bold"}
+        )
     elif title:
         ax.set_title(latexify(title), size=ax_fontsize * width, fontdict={"fontweight": "bold"})
     if saved or filename:
