@@ -1,11 +1,5 @@
 #!/usr/bin/env python
 
-__author__ = "Seán Kavanagh"
-__copyright__ = "MIT License"
-__version__ = "0.0.1"
-__maintainer__ = "Seán Kavanagh"
-__email__ = 'sean.kavanagh.19@ucl.ac.uk'
-__date__ = "May 19, 2020"
 
 from math import sqrt, pi, exp
 from collections import defaultdict
@@ -46,11 +40,11 @@ def freysoldt_correction_from_paths(defect_file_path, bulk_file_path, dielectric
     """
     sdp = SingleDefectParser.from_paths(defect_file_path, bulk_file_path, dielectric, defect_charge)
     _ = sdp.freysoldt_loader()
-    plt_title = os.path.join(defect_file_path,
-                             "{}_chg_{}".format(sdp.defect_entry.name, defect_charge)) if plot else None
+    if plot:
+        print(f"{sdp.defect_entry.name}, charge = {defect_charge}")
     correction = get_correction_freysoldt(sdp.defect_entry,
                                           dielectric,
-                                          title=plt_title)
+                                          plot=plot)
 
     return correction
 
