@@ -12,8 +12,6 @@ If you use the corrections implemented in this module, cite
     Phys. Status Solidi B. 248, 1067-1076 (2011)  and
 in addition to the pycdt paper
 """
-__author__ = 'Danny Broberg, Bharat Medasani'
-__email__ = 'dbroberg@gmail.com, mbkumar@gmail.com'
 
 import math
 import logging
