@@ -1,12 +1,6 @@
 #!/usr/bin/env python
 
-__author__ = "Bharat Medasani"
-__copyright__ = "Copyright 2014, The Materials Project"
-__version__ = "1.0"
-__maintainer__ = "Bharat Medasani"
-__email__ = "mbkumar@gmail.com"
 __status__ = "Development"
-__date__ = "Jul 24, 2016"
 
 import os
 import logging
